Those from Mexico will benefit most from Obama’s executive action | Pew Research Center
Date: 20141120

Skip to Content

Numbers, Facts and Trends Shaping Your World

MenuProjects
Fact Tank - Our Lives in Numbers
November 20, 2014

# Those from Mexico will benefit most from Obama’s executive action

By Jens Manuel Krogstad and Jeffrey S. Passel 24 comments

Unauthorized immigrants from Mexico account for two-thirds of those who will be eligible for deportation relief under President Obama’s executive action, even as they account for about half of the nation’s unauthorized population, according to a new Pew Research Center analysis.

The new action, which mainly applies to unauthorized immigrant parents of U.S. citizen or legal permanent resident children, would benefit those born in Mexico more than any other country of origin group. According to the Pew Research analysis, 44% of unauthorized immigrants from Mexico could apply for deportation protection under the new programs, compared with 24% of those from other parts of the world.

President Obama’s new programs could affect about 4 million total unauthorized immigrants who will be eligible for deportation protection and a three-year work permit. The largest group — at least 3.5 million, according to Pew Research estimates of 2012 data — consists of unauthorized immigrant parents who have lived in the U.S. for at least five years and have children who either were born in the U.S. or are legal permanent residents. Of these, about 700,000 have adult children and the remaining 2.8 million have children younger than 18.

The new policy also expands eligibility for the president’s Deferred Action for Childhood Arrivals (DACA) program that benefits young adults brought to the U.S. illegally as children. The program would allow an additional 330,000 people, according to our estimates, to apply for and receive temporary deportation relief. Previously, the program was available only to those up to age 30, but the executive action would lift that age cap. In addition, the program would allow immigrants who arrived as children illegally before Jan. 1, 2010 to become eligible, expanding the program beyond the original June 15, 2007 cutoff date.

In some cases, the Obama administration’s estimates of how many would be affected differ from those calculated by Pew Research. For example, the government estimates that more than 4 million parents of U.S. citizen children or legal permanent residents could apply for relief compared with our 3.5 million figure. One possible difference is that the data Pew Research uses only includes parents who live with their children.

While work permits and deportation relief will be available, those covered by the programs will not be eligible for certain government benefits, including subsidies for health care under the Affordable Care Act.

Among the other policy changes announced in the president’s action are an increased number of visas for skilled workers and spouses of green card holders. There are several changes, including immigration enforcement that will now focus on recent arrivals and serious and repeat criminal offenders.

Even though about 4 million unauthorized immigrants may be eligible for deportation relief, it remains to be seen how many people will apply for and receive it. Response to the existing DACA program may offer a clue. The 2012 program allowed an estimated 1.1 million people ages 30 or younger to become eligible for deportation relief and receive a two-year work permit. But through June 30, 2014, only about 712,000 applied.

The general public disapproves of Obama taking executive action on immigration, by a margin of 48% to 38%, according to a NBC News/Wall Street Journal survey conducted this month. While Americans may not generally support an executive action, the poll found 57% favor a pathway to citizenship for undocumented immigrants, with support increasing to 74% when respondents are given a scenario in which a pathway requires paying fines, back taxes and taking other steps.

According to a recent Pew Research Center survey, Hispanics place a priority on the relief from deportation offered by the executive action. By 56% to 35%, Hispanics said it is more important that unauthorized immigrants be able to live and work in the U.S. without threat of deportation than have a pathway to citizenship.

The estimated 4 million covered under the executive action are in addition to an estimated 1.5 million unauthorized immigrants who are eligible for temporary relief from deportation through either the Deferred Action for Childhood Arrivals program or having Temporary Protected Status.

The president’s executive action offers deportation relief for the largest number of unauthorized immigrants in recent history. However, the current action does not allow unauthorized immigrants the opportunity to obtain permanent residency or citizenship. Only Congress has the authority to offer a path to legal status, which means those eligible for relief under the new policy remain unauthorized. If a future administration reverses course or if Congress passes an immigration law, the protection from deportation could be taken away.

Correction: This posting has been updated with a revised total of 3.9 million unauthorized immigrants affected by the president’s action, and other related revised estimates. A previous version of this post referred to the president’s implementation of his new immigration policy as an executive order. He has taken executive action.

Topics: Immigration, Unauthorized Immigration

Share the link:

1. Jens Manuel Krogstad is a Writer/Editor at the Pew Research Center's Hispanic Trends Project.

   - Posts
   - Email
   - @jensmanuel

2. Jeffrey S. Passel is Senior Demographer at the Pew Research Center’s Hispanic Trends Project.

   - Posts
   - Email
   - Bio

Get Pew Research data by email

### Leave a Comment

Cancel Reply

Log In with Facebook

Sign In with Google

Or

Name Email (will not be published)
Current Year (YYYY)
Leave this field blank

All comments must follow the Pew Research comment policy and will be moderated before posting.

## 24 Comments

1. MA Sullivan • 2 weeks ago

   To refer to this population as “unauthorized” instead of “illegal” is to obfuscat the most significant and devisive characteristic of this population. They came to this country illegally. They broke SIGNIFICANT laws. To refer to them as “unauthorized” implies a lessor offense than breaking a law. Why is the left so afraid to call something by its real name? “Undocumented” or “unauthorized ” be “illegal.” “Choice vs child.”. ” Contribution “vs ‘Tax.”. Are they afraid the truth may undermine their argument. To use a word like “unauthorized’ is to practice advocacy journalism. Polling is supposed to be about uncovering truth.

   Reply

2. MsElmeno • 2 weeks ago

   HOLA or HI to all HARD WORKING AMERICAN Readers. I have two question? for ALL of you. HAVE any of you live or spent time with an Illegal person? HAVE YOU ever set on a table to talk about how they affects you as a US citizen?

   Reply

3. Dee Rothman • 3 weeks ago

   Nice article but how about one that addresses how this will affect US citizens, both native born and naturalized, employed and unemployed? Or how will it affect the job market as new legal aliens come out of the shadows and compete with US citizens, both native born and naturalized, employed and unemployed, in a job market which cannot currently even support the number of people seeking employment. Even anecdotal analysis should suggest the number of unemployed should increase. Less apparent should be the affect on wages and hours of work available for employees, which would seem to substantiate the contention the policy was a courageous move by Obama, because US citizens, both native born and naturalized, employed and unemployed, will on average, see personal income falling and understand the policy hurt them. Will they still vote blue? Those who finally felt the hurt caused by Obama’s changes the last six years didn’t hang blue, did they? My medical insurance went up over $2000 annually and my disposable income fell by about 6 percent. Who are the people most hurt by this and other policies and laws enacted under Obama? The MIDDLE CLASS, PERIOD!

   Reply

4. Me • 3 weeks ago

   All smoke and mirrors, no guaranties, and it’s only good for three years. Trick to get Latino votes in 2016, and maybe draw the GOP into fight to try to make them look bad … again. Notice how all the stuff that he does always kicks the can just past an election, I think people are getting wise to his lies and his tricks.

   Reply

5. welington • 3 weeks ago

   What about people living in USA for about 15 years and have a unsolved case of deportation hanging over their heads? Would they be eligible for the Executive Action?

   Reply

   1. hmm • 2 weeks ago

      hopefully not!!

      Reply

6. NOamnestyEVER • 3 weeks ago

   ……………. more than 70% of illegals will receive welfare. ALL WILL GET JOBS.

   “THE AMNESTY ALONE WILL BE THE LARGEST EXPANSION OF THE WELFARE SYSTEM IN THE LAST 25 YEARS” ….. Heritage Foundation

   Reply

7. NOamnestyEVER • 3 weeks ago

   “The President is providing an estimated 5 million illegal immigrants with social security numbers, photo IDs, and work permits—allowing them to now take jobs directly from struggling Americans during a time of record immigration, low wages, and high joblessness.” SEN. JEFF SESSIONS

   Reply

   1. MsElmeno • 2 weeks ago

      You must be a berry hard working American. if so, non of this will affect you, or any hard working American.

      Reply

   2. Y.M. • 2 weeks ago

      Historically Mexicans were disenfranchised as a whole by the Anglo-Saxon population. “The arrival of large numbers of Mexican immigrants threatened the precarious socioeconomic status of those already living in the Southwest (This is referring to the Treaty of Guadalupe Hidalgo). Since the majority of immigrants from Mexico (are) poor they (are) willing to to accept the lowest wages; as a consequence, the White American population tends to regard all Mexicans, including descendants of the original landholders in the Southwest, as “cheap labor.” Indigenous Mexican Americans were perceived by the Anglo core as no different from poor Mexican immigrants- a perception that pushed almost all those of Mexican extraction to the bottom rungs of the stratification system (Aguirre and Turner). Given the background of Mexicans and the United States, what jobs exactly are being taken from the U.S. citizens? Mexicans have been relegated to the bottom which usually means that the jobs available to them are the most undesirable ones. And by undesirable jobs I mean hard manual work, field work, low pay jobs, there is a niche created in the economy for agriculture but people fail to see who reaps the profits, that the corporate powers reap the all PROFITS. This isn’t limited to just Mexicans. If immigrants have presented themselves as a threat to your well being I would encourage you to research your American History, and I mean Real History, no the Patriot Loving Agenda that is instilled in students in high school.

      Reply

8. Ted • 3 weeks ago

   Can someone explain how an undocumented, illegal immigrant “living in the shadows” proves he/she has been in the this country for 5 or more years? I’m sure there is a way for a fee. Perhaps a Coyote can help with this paperwork. Especially, if they have an established account with them. There is a business opportunity here! Just like getting help applying for VA benefits.

   Reply

   1. hmm • 3 weeks ago

      good point. Also how do they prove their kids were born here?

      Reply

      1. YOU • 2 weeks ago

         There are documents, birth certificates, pictures, ect.

         Reply

9. Gerald FitzGerald • 3 weeks ago

   Correction to my comment. I misread the graphs’s gold part ( 1.5 million) as an extension of DOMA, so the graph does answer a question I asked.

   Reply

10. Gerald FitzGerald • 3 weeks ago

    I would like to see legal arguments for and against the constitutionality and legality of President Obama’s executive action on immigration.

    Thanks for clarifying who and how many immigrants are covered by the recent action. I would like to have seen, in this article, the group covered by DOMA or other relevant actions pertaining to the estimated 11.2 million undocumented, with a percentage of the undocumented (illegally entered) total who are deferred by some executive actions and orders.

    Reply

11. Joseph • 3 weeks ago

    Duh! They are the closest to the U S and have the most undocumented here.

    Reply

12. Greg Johnson • 3 weeks ago

    Your query and research is very much on point as it always is. However, I have a query that has puzzled me from the very beginning of the Immigration talks. Nearly everything I’ve heard or read has been in reference to those persons from Mexico or are native to Mexico. Is there not a equal or greater concern with those persons crossing the border from the North or Canada?
    Based on research I have regarding prostitution and drug trafficking, the patterns are very similar North and South. I have every reason to believe the drain on job occupancy is equal to the Mexican neighbors and probably even greater among our neighbors from the North.
    So, why no equal uproar, discussion or inclusion in the discussion regarding immigration?

    Reply

    1. hmm • 3 weeks ago

       Not likely. Canada is not currupt from top to bottom, like Mexico and most of South and Central America. They have a legitimate government, with an educated population.

       Reply

13. Carlos • 4 weeks ago

    It is not so clear about who is covered and who is not. Because of that there is a punctual question: somebody that has been in the U.S for 10 years, has paid taxes, has no felonies, but at the same time is not a parent of a u.s citizen and entered the u.s as an adult (no DACA) can be elegible for the protection?

    Reply

14. Tess • 4 weeks ago

    My question is …Why the did not move the age of sixteen to eighteen in the new illegibility for DACA? any particular reason?

    Reply

15. Packard Day • 4 weeks ago

    In defense of our President, this new immigration initiative will also do nothing but strongly enhance the 401k/IRA investment portfolios of America’s top 10%. It will also marginally help all those living in the next 40% of income brackets as well. Just as long as you or yours are not low skilled and/or low educated workers or are not currently holding down a job that can be easily replaced with a week’s worth of training, you are going to be okay. No worries.

    Truth be told, Barack Obama’s administration and his policies have given us all profit margins in our S&P 500 accounts that have not been seen in more than a generation. So, here’s a plea to just let the President and the good times continue to roll.

    Oh, and God bless America too…ehh?

    Reply

16. Bert Pace • 4 weeks ago

    Thanks to the President for the courage he showed in taking action on Immigration. How many more years will America have to wait for Mr. Boehner to do his job and actually produce a bi-partisan Bill the President will sign? If actually crafting a Bill is too difficult for the House, why not put the bi-partisan Senate Bill they have had for 511 days up for a vote?Pretty simple solution – if only the GOP was interested in solutions.

    Reply

    1. Ted • 3 weeks ago

       Courage? It doesn’t take courage to be political and that is exactly what this is. Enforcing the existing laws would have been courageous. None of the Presidents starting with Carter had the guts to stop illegal immigration. Now look what a mess this has become.

       Reply

    2. hmm • 2 weeks ago

       It is no US representative or senator’s job to create a bill to benefit the citizens of foreign countries. The only people crying for immigration “reform” are US and foreign companies wishing to bring cheap labor in and undercut our own citizens, and foreign nationals who believe it is their “right” to benefit from sneaking into the US. They believe once they broke in, started having children here (which is their choice of course) , and have evaded the law long enough that they are owed a voice and legal status in the US. People that sneak in are owed nothing but a boot back across the border, and companies that want to undercut our own people should lose the benefits of operating here.

       Reply

- Copyright 2014 Pew Research Center
- Terms & Conditions
- Privacy Policy
- Reprints, Permissions & Use Policy
- Feedback
- Careers
- Find an Expert